@@ -6,7 +6,9 @@
 # write.bibtex(file="references.bib")
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  install.packages("coxmeg", repos="http://R-Forge.R-project.org")
+#  install.packages("devtools")
+#  library(devtools)
+#  install_github("lhe17/coxmeg")
 
 ## ----echo=TRUE----------------------------------------------------------------
 library(coxmeg)
@@ -91,9 +93,8 @@ pheno_m = read.table(pheno)
 re = coxmeg_m(geno,pheno_m[,3:4],sigma,type='bd',verbose=FALSE)
 re
 
-## ----echo=TRUE----------------------------------------------------------------
-re = coxmeg_plink(pheno,sigma,type='dense',bed=bed,tmp_dir=tempdir(),cov_file=cov,detap='slq',verbose=FALSE,solver=2)
-re
+## ----echo=TRUE,eval=FALSE-----------------------------------------------------
+#  re = coxmeg_plink(pheno,sigma,type='dense',bed=bed,tmp_dir=tempdir(),cov_file=cov,detap='slq',verbose=FALSE,solver=2)
 
 ## ----echo=TRUE----------------------------------------------------------------
 re = coxmeg_plink(pheno,sigma,type='dense',bed=bed,tmp_dir=tempdir(),tau=re$tau,cov_file=cov,detap='slq',verbose=FALSE,solver=2,score=TRUE)
